@@ -64,6 +64,12 @@ class JobMetricsClient(BaseClient):
             raise AdminError("Unable to get table group info")
 
     def get_ingestion_metrics(self, job_id, source_id):
+        """
+        Function to get ingestion metrics for the job
+        :param job_id: Entity identifier of the job
+        :param source_id: Entity identifier of the source
+        :return: List of job metrics
+        """
         try:
             combinedJobMetric = []
             url_to_get_job_ingestion_metrics = url_builder.get_job_metrics_url(self.client_config, source_id,
@@ -141,7 +147,7 @@ class JobMetricsClient(BaseClient):
     def get_pipeline_build_metrics(self, job_id):
         try:
             combinedJobMetric = []
-            url_to_get_pipeline_build_metrics = url_builder.get_export_metrics_url(self.client_config,
+            url_to_get_pipeline_build_metrics = url_builder.get_pipeline_build_metrics_url(self.client_config,
                                                                                    job_id) + "?limit=50&offset=0"
             response = IWUtils.ejson_deserialize(
                 self.call_api("GET", url_to_get_pipeline_build_metrics,
@@ -319,6 +325,16 @@ class JobMetricsClient(BaseClient):
             raise AdminError("Unable to get pipeline NAME")
 
     def get_source_jobs_metrics_results(self, date_string, source, workflow_id=None, workflow_run_id=None):
+        """
+        Gets the Infoworks source job metrics
+        :param date_string: date string to fetch the data till that date
+        :type date_string: String
+        :param workflow_id: Workflow id to get the jobs
+        :type workflow_id: String
+        :param workflow_run_id: Workflow run id to get the jobs
+        :type workflow_run_id: String
+        :return: response dict
+        """
         src_name = source["name"]
         list_of_jobs_obj = self.get_jobs_of_single_source(source["id"], date_string)
         try:
@@ -575,7 +591,20 @@ class JobMetricsClient(BaseClient):
             print(str(e))
             traceback.print_exc()
 
-    def get_pipeline_build_metrics_results(self, job, workflow_id=None, workflow_run_id=None):
+    def get_pipeline_build_metrics_results(self, job=None, workflow_id=None, workflow_run_id=None):
+        """
+        Gets the Infoworks pipeline build metrics
+        :param job: job object to get the pipeline build metrics details
+        :type job: JSON Object
+        :param workflow_id: Workflow id to get the jobs
+        :type workflow_id: String
+        :param workflow_run_id: Workflow run id to get the jobs
+        :type workflow_run_id: String
+        :return: response dict
+        """
+        if job is None:
+            self.logger.error("job is a mandatory parameter")
+            raise Exception("job is a mandatory parameter")
         temp = []
         job_id = job['id']
         job_type = job['type']
@@ -665,7 +694,17 @@ class JobMetricsClient(BaseClient):
                     temp.append(od)
             self.job_metrics_final.extend(temp)
 
-    def get_abc_job_metrics(self, time_range_for_jobs_in_mins, workflow_id=None, workflow_run_id=None):
+    def get_abc_job_metrics(self, time_range_for_jobs_in_mins=5, workflow_id=None, workflow_run_id=None):
+        """
+        Gets the Infoworks Job metrics
+        :param time_range_for_jobs_in_mins: time range to look out for Infoworks jobs (default 5mins)
+        :type time_range_for_jobs_in_mins: Integer
+        :param workflow_id: Workflow id to get the jobs
+        :type workflow_id: String
+        :param workflow_run_id: Workflow run id to get the jobs
+        :type workflow_run_id: String
+        :return: response dict
+        """
         try:
             sources_info = self.get_source_info()
             delay = int(time_range_for_jobs_in_mins)
@@ -687,11 +726,14 @@ class JobMetricsClient(BaseClient):
 
             result = []
             header = ['workflow_id', 'workflow_run_id', 'job_id', 'entity_type', 'job_type', 'job_start_time', 'job_end_time', 'job_status', 'source_name', 'source_file_names', 'source_schema_name', 'source_database_name', 'table_group_name', 'iwx_table_name', 'starting_watermark_value', 'ending_watermark_value', 'target_schema_name', 'target_table_name', 'pre_target_count', 'fetch_records_count', 'target_records_count', 'job_link']
+            ui_port = 443 if self.client_config["port"]=='443' else 3000
             if len(self.job_metrics_final) > 0:
                 for item in self.job_metrics_final:
                     dict_temp = {}
                     for i in header:
                         dict_temp[i] = item.get(i)
+                        if i=="job_link" and dict_temp.get("job_id",None)!=None:
+                            dict_temp[i]=f"{self.client_config['protocol']}://{self.client_config['ip']}:{ui_port}/job/logs?jobId={dict_temp.get('job_id','')}"
                     result.append(copy.deepcopy(dict_temp))
                 return result
             else:
