@@ -1,9 +1,9 @@
 POLLING_FREQUENCY_IN_SEC = 15
 NUM_POLLING_RETRIES = 3
-POLLING_TIMEOUT = 300
+POLLING_TIMEOUT = 1200
 NUM_FAILURE_RETRIES = 5
 RUNNING_JOB_LOGGING_COUNTER = 10
-REQUEST_TIMEOUT_IN_SEC = 10
+REQUEST_TIMEOUT_IN_SEC = 60
 MAX_RETRIES = 1
 LOG_LOCATION = "/tmp/iwx_sdk.log"
 
@@ -44,6 +44,7 @@ class Job(object):
 
 
 class ErrorCode(object):
+    POLL_TIMEOUT = 1408
     ENTITY_NOT_FOUND = 1400
     DEPENDENT_ENTITY_NOT_FOUND = 1401
     ENTITY_STATE_INCONSISTENT = 1402
@@ -58,3 +59,12 @@ class ErrorCode(object):
     RESOURCE_NOT_FOUND = 404
     USER_ERROR = 1406
     GENERIC_ERROR = 1407
+
+
+class SourceMappings(object):
+    oracle = {"sub_type": "oracle", "driver_name": "oracle.jdbc.driver.OracleDriver", "driver_version": "v2",
+              "database": "ORACLE"}
+    teradata = {"sub_type": "teradata", "driver_name": "com.teradata.jdbc.TeraDriver", "driver_version": "v2",
+                "database": "TERADATA"}
+    netezza = {"sub_type": "netezza", "driver_name": "org.netezza.Driver", "driver_version": "v2",
+               "database": "NETEZZA"}
