@@ -34,6 +34,19 @@ def list_domains_url(config):
     return request
 
 
+def list_pipelines_url(config, domain_id):
+    """
+    returns URL to list pipelines under given domain using v3 api
+    :param config: client configurations
+    :type config: dict
+    :return: url to list pipelines
+    """
+    request = '{protocol}://{ip}:{port}/v3/domains/{domain_id}/pipelines'.format(ip=config['ip'], port=config['port'],
+                                                                                 protocol=config['protocol'],
+                                                                                 domain_id=domain_id)
+    return request
+
+
 def list_sources_url(config):
     """
     returns URL to list sources using v3 api
@@ -337,7 +350,7 @@ def add_user_to_domain_url(config, user_id):
 
     :param config: client configurations
     :type config: dict
-    :param user_id: Identifier for user id
+    :param user_id: Identifier for user
     :type user_id: string
     :return: url for the add user to domain
     """
@@ -354,7 +367,7 @@ def add_sources_to_domain_url(config, domain_id):
 
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
     :return: url to add sources to domains
     """
@@ -370,7 +383,7 @@ def create_pipeline_url(config, domain_id):
     returns URL to create pipeline using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
     :return: url for the pipeline creation
     """
@@ -385,9 +398,9 @@ def get_pipeline_url(config, domain_id, pipeline_id):
     returns URL to get pipeline details using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
-    :param pipeline_id: Identifier for pipeline_id
+    :param pipeline_id: Identifier for pipeline
     :type pipeline_id: string
     :return: url get pipeline details
     """
@@ -405,9 +418,9 @@ def delete_pipeline_url(config, domain_id, pipeline_id):
     returns URL to delete pipeline using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
-    :param pipeline_id: Identifier for pipeline_id
+    :param pipeline_id: Identifier for pipeline
     :type pipeline_id: string
     :return: url to delete pipeline details
     """
@@ -425,9 +438,9 @@ def update_pipeline_url(config, domain_id, pipeline_id):
     returns URL to update pipeline using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
-    :param pipeline_id: Identifier for pipeline_id
+    :param pipeline_id: Identifier for pipeline
     :type pipeline_id: string
     :return: url to update pipeline details
     """
@@ -445,9 +458,9 @@ def configure_pipeline_url(config, domain_id, pipeline_id):
     returns URL to configure pipeline using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
-    :param pipeline_id: Identifier for pipeline id
+    :param pipeline_id: Identifier for pipeline
     :type pipeline_id: string
     :return: url to configure pipeline
     """
@@ -464,9 +477,9 @@ def list_pipeline_versions_url(config, domain_id, pipeline_id):
     returns URL to list pipeline versions using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
-    :param pipeline_id: Identifier for pipeline id
+    :param pipeline_id: Identifier for pipeline
     :type pipeline_id: string
     :return: url to list pipeline versions
     """
@@ -483,11 +496,11 @@ def make_pipeline_version_active_url(config, domain_id, pipeline_id, version_id)
     returns URL to make pipeline version active
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
-    :param pipeline_id: Identifier for pipeline id
+    :param pipeline_id: Identifier for pipeline
     :type pipeline_id: string
-    :param version_id: Identifier for pipeline id
+    :param version_id: Identifier for pipeline
     :type version_id: string
     :return: url to make pipeline version active
     """
@@ -505,7 +518,7 @@ def create_workflow_url(config, domain_id):
     returns URL to create workflow using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
     :return: url for the workflow creation
     """
@@ -520,9 +533,9 @@ def configure_workflow_url(config, domain_id, workflow_id):
     returns URL to configure workflow using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
-    :param workflow_id: Identifier for workflow id
+    :param workflow_id: Identifier for workflow
     :type workflow_id: string
     :return: url to configure workflow
     """
@@ -536,12 +549,12 @@ def configure_workflow_url(config, domain_id, workflow_id):
 
 def trigger_workflow_url(config, domain_id, workflow_id):
     """
-    returns URL to configure workflow using v3 api
+    returns URL to trigger a workflow using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
+    :param domain_id: Identifier for domain
     :type domain_id: string
-    :param workflow_id: Identifier for workflow id
+    :param workflow_id: Identifier for workflow
     :type workflow_id: string
     :return: url to trigger workflow
     """
@@ -585,38 +598,110 @@ def get_all_workflows_url(config):
     return request
 
 
-def create_data_connection(config, domain_id):
+def get_all_workflows_runs_url(config):
+    """
+    returns URL to fetch all workflows runs in Infoworks using v3 api
+    :param config: client configurations
+    :type config: dict
+    :return: url fetch all workflows in Infoworks using v3 api
+    """
+    request = '{protocol}://{ip}:{port}/v3/prodops/workflow_runs'.format(
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def get_all_workflow_run_jobs_url(config, run_id):
+    """
+    returns URL to fetch all workflows run jobs in Infoworks using v3 api
+    :param config: client configurations
+    :type config: dict
+    :param run_id: Workflow run id to get the jobs under it
+    :type run_id: String
+    :return: url fetch all workflows in Infoworks using v3 api
+    """
+    request = '{protocol}://{ip}:{port}/v3/prodops/workflow_runs/{run_id}/jobs'.format(
+        run_id=run_id,
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def restart_multiple_workflows_url(config):
+    """
+    returns URL to restart multiple workflows using Infoworks using v3 api
+    :param config: client configurations
+    :type config: dict
+    :return: url restart multiple workflows using Infoworks using v3 api
+    """
+    request = '{protocol}://{ip}:{port}/v3/prodops/workflows/restart'.format(
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def cancel_multiple_workflows_url(config):
+    """
+    returns URL to cancel multiple workflows using Infoworks using v3 api
+    :param config: client configurations
+    :type config: dict
+    :return: url cancel multiple workflows using Infoworks using v3 api
+    """
+    request = '{protocol}://{ip}:{port}/v3/prodops/workflows/cancel'.format(
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def get_all_workflows_runs_url_with_domain_id(config, domain_id, workflow_id):
+    """
+    returns URL to fetch all workflows runs in Infoworks using v3 api
+    :param config: client configurations
+    :type config: dict
+    :return: url fetch all workflows in Infoworks using v3 api
+    """
+    request = '{protocol}://{ip}:{port}/v3/domains/{domain_id}/workflows/{workflow_id}/runs'.format(
+        domain_id=domain_id,
+        workflow_id=workflow_id,
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def create_data_connection(config):
     """
     returns URL to create data connection using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
-    :type domain_id: string
     :return: url for data connection creation
     """
-    request = '{protocol}://{ip}:{port}/v3/domains/{domain_id}/data-connections'.format(ip=config['ip'],
-                                                                                        port=config['port'],
-                                                                                        protocol=config['protocol'],
-                                                                                        domain_id=domain_id)
+    request = '{protocol}://{ip}:{port}/v3/admin/data-connections'.format(ip=config['ip'],
+                                                                          port=config['port'],
+                                                                          protocol=config['protocol']
+                                                                          )
     return request
 
 
-def get_data_connection(config, domain_id, dataconnection_id):
+def get_data_connection(config, dataconnection_id=None):
     """
     returns URL to get data connection details using v3 api
     :param config: client configurations
     :type config: dict
-    :param domain_id: Identifier for domain_id
-    :type domain_id: string
     :param dataconnection_id: Identifier for data connection
     :type dataconnection_id: string
     :return: url to get data connection details
     """
-    request = '{protocol}://{ip}:{port}/v3/domains/{domain_id}/data-connections/{dataconnection_id}'.format(
-        ip=config['ip'],
-        port=config['port'],
-        protocol=config['protocol'],
-        domain_id=domain_id, dataconnection_id=dataconnection_id)
+    if dataconnection_id is None:
+        request = '{protocol}://{ip}:{port}/v3/admin/data-connections'.format(
+            ip=config['ip'],
+            port=config['port'],
+            protocol=config['protocol'])
+    else:
+        request = '{protocol}://{ip}:{port}/v3/admin/data-connections/{dataconnection_id}'.format(
+            ip=config['ip'],
+            port=config['port'],
+            protocol=config['protocol'],
+            dataconnection_id=dataconnection_id)
     return request
 
 
@@ -913,7 +998,7 @@ def get_table_configuration(config, source_id, table_id):
     return request
 
 
-def update_table_config_url(config, source_id, table_id):
+def update_table_ingestion_config_url(config, source_id, table_id):
     """
     returns URL to update the table configurations using v3 rest apis
     :param config: client configurations
@@ -1021,7 +1106,7 @@ def get_export_metrics_url(config, job_id):
 
 
 def get_pipeline_build_metrics_url(config, job_id):
-    request = '{protocol}://{ip}:{port}/v3/admin/jobs/{job_id}/reports/pipeline-metrics?limit=50&offset=0'.format(
+    request = '{protocol}://{ip}:{port}/v3/admin/jobs/{job_id}/reports/pipeline-metrics'.format(
         ip=config['ip'],
         port=config['port'],
         protocol=config['protocol'],
@@ -1069,3 +1154,123 @@ def unlock_locked_entities(config):
                                                                          port=config['port'],
                                                                          protocol=config['protocol'])
     return request
+
+
+def trigger_pipeline_build_url(config, domain_id, pipeline_id):
+    """
+    returns URL to trigger pipeline
+    :param config: client configurations
+    :type config: dict
+    :param domain_id: Identifier for domain_id
+    :type domain_id: string
+    :param pipeline_id: Identifier for pipeline
+    :type pipeline_id: string
+    :return: url to trigger pipeline
+    """
+    request = '{protocol}://{ip}:{port}/v3/domains/{domain_id}/pipelines/{pipeline_id}/jobs'.format(
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'],
+        domain_id=domain_id,
+        pipeline_id=pipeline_id)
+    return request
+
+
+def create_source_extension_url(config):
+    """
+    returns URL to create source extension
+    :param config: client configurations
+    :type config: dict
+    :return: url to create source extension
+    """
+    request = '{protocol}://{ip}:{port}/v3/admin/source-extensions'.format(
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def get_jobs_url(config):
+    """
+    returns URL to get jobs details
+    :param config: client configurations
+    :type config: dict
+    :return: URL to get jobs details
+    """
+    request = '{protocol}://{ip}:{port}/v3/admin/jobs'.format(
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def get_interactive_jobs_url(config, source_id):
+    """
+    returns URL to get interactive jobs details
+    :param config: client configurations
+    :type config: dict
+    :param source_id: Id of the source
+    :type source_id: String
+    :return: URL to get jobs details
+    """
+    request = '{protocol}://{ip}:{port}/v3/sources/{source_id}/interactive-jobs'.format(
+        source_id=source_id,
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def get_admin_jobs_url(config):
+    """
+    returns URL to get jobs details
+    :param config: client configurations
+    :type config: dict
+    :return: URL to get jobs details
+    """
+    request = '{protocol}://{ip}:{port}/v3/admin/admin-jobs'.format(
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def get_pipeline_jobs_url(config, domain_id, pipeline_id):
+    """
+    returns URL to get jobs details
+    :param config: client configurations
+    :type config: dict
+    :param domain_id: Id of the domain for given pipeline
+    :type domain_id: String
+    :param pipeline_id: Id of the pipeline
+    :type pipeline_id: String
+    :return: URL to get jobs details
+    """
+    request = '{protocol}://{ip}:{port}/v3/domains/{domain_id}/pipelines/{pipeline_id}/jobs'.format(
+        domain_id=domain_id,
+        pipeline_id=pipeline_id,
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def get_cancel_job_url(config, job_id):
+    """
+    returns URL to get jobs details
+    :param config: client configurations
+    :type config: dict
+    :param job_id: Id of job to cancel
+    :type job_id: String
+    :return: URL to get jobs details
+    """
+    request = '{protocol}://{ip}:{port}/v3/prodops/jobs/{job_id}/cancel'.format(
+        job_id=job_id,
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
+
+
+def get_query_as_table_url(config, source_id):
+    """
+        returns URL to create query as table
+    """
+    request = '{protocol}://{ip}:{port}/v3/sources/{source_id}/tables/query_tables'.format(
+        source_id=source_id,
+        ip=config['ip'], port=config['port'],
+        protocol=config['protocol'])
+    return request
